@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 13/02/2020
+#Date last Update : 14/07/2021
 
 import vmpsys    as sys
 import vmpconfig as config
@@ -93,20 +93,17 @@ class clib:
     sobj="{0}{1}.so".format(self.libpath,self.name)
     setup.deprun[self.name]=self
     dependencies(self.dependencies,setup)
-    coptions=self.coptions
-    for d in self.dependencies:
-      coptions=coptions+clibs_[d].coptions
+    setup.coptions=setup.coptions+self.coptions
     if not sys.isfile(sobj):
       check(self.cmd,self.hdr,self.libs)
       if self.config:
         sys.config_create("{0}config.h".format(sys.path(config.fwsrc_)),config.configlist_)
       try:
-        objfiles=sys.compiler(path,config.cpp_(included_,coptions),self.files)
-        sys.linker(path,config.cppso_(self.loptions),objfiles,sobj)
+        objfiles=sys.compiler(path,config.cpp_(included_,setup.coptions),self.files) + setup.sobject
+        sys.linker(path,config.cppso_(),objfiles,self.loptions,sobj)
       except Exception as e:
         sys.msg_failure("Build Lib \'{0}\'".format(self.name),e)
     setup.sobject.append(sobj)
-    setup.coptions=setup.coptions+self.coptions
     sys.msg_ok("Build Lib \'{0}\'".format(self.name))
 
   #Uninstall library 
@@ -128,14 +125,14 @@ vmplib=clib()
 vmplib.name='vmp'
 vmplib.hdr=['assert.h','dirent.h','errno.h','fcntl.h','pthread.h','pty.h','signal.h','sys/time.h','sys/stat.h','sys/types.h','sys/wait.h','sys/ioctl.h','net/if.h','string.h','strings.h','stdarg.h','stdio.h','stdlib.h','time.h','unistd.h']
 vmplib.files=[('./',['args','basetypes','buf','env','error','io','lib','math','signal','thread','time','unicode','utils'])]
-vmplib.loptions=['-lpthread','-lutil']
+vmplib.loptions=['-pthread','-lutil']
 vmplib.config=True
 clibs_[vmplib.name]=vmplib
 
 pylib=clib()
 pylib.name='pylib'
 pylib.files=[('./',['args','lib','module','stub']),('lib/',['arg_from_python','class_impl','converter','def','pybase'])]
-pylib.libs=[('python3','3.5')]
+pylib.libs=[('python3','3.9')]
 pylib.coptions=['`pkg-config --cflags python3`']
 pylib.loptions=['`pkg-config --libs python3`']
 pylib.dependencies=['vmp']
@@ -170,7 +167,7 @@ xmllib=clib()
 xmllib.name='xml'
 xmllib.files=[('./',['parser','xml'])]
 xmllib.dependecies=['vmp']
-xmllib.libs=[('libxml++-2.6','2.36.0')]
+xmllib.libs=[('libxml++-2.6','2.40.1')]
 xmllib.coptions=['`pkg-config libxml++-2.6 --cflags --libs`']
 xmllib.loptions=['`pkg-config libxml++-2.6 --cflags --libs`']
 clibs_[xmllib.name]=xmllib
@@ -181,3 +178,12 @@ moduleslib.files=[('./',['modules','modinput','modparser'])]
 moduleslib.dependencies=['vmp','process','xml','net']
 clibs_[moduleslib.name]=moduleslib
 
+jsonlib=clib()
+jsonlib.name='json'
+jsonlib.dependencies=['vmp']
+jsonlib.files=[('./',['json'])]
+jsonlib.libs=[('json-c','0.15')]
+jsonlib.loptions=['`pkg-config json-c --cflags --libs`']
+clibs_[jsonlib.name]=jsonlib
+
+
