@@ -138,8 +138,17 @@ packet.setup.files=[('./',['packet_'])]
 packet.setup.dependencies=['vmp','pylib','packet']
 pylibs_[packet.name]=packet
 
-vmp_plugin=pylib()
-vmp_plugin.name='vmp_plugin'
-vmp_plugin.dependencies=[]
-pylibs_[vmp_plugin.name]=vmp_plugin
+plugin=pylib()
+plugin.name='vmp_plugin'
+plugin.dependencies=[]
+pylibs_[plugin.name]=plugin
+
+json=pylib()
+json.name='vmp_json'
+json.dependencies=['vmp']
+json.cbuild()
+json.setup.files=[('./',['json_'])]
+json.setup.dependencies=['vmp','pylib','json']
+pylibs_[json.name]=json
+
 
