@@ -228,7 +228,7 @@ void fd_close(vmp_int *fd);
 //! Exec a command and return after the command has been completed
 /*!
     @param cmd input command
-    @return (except error)execve()
+    @return (except error)
 */
 void system_wrap(vmp::str cmd);
 
