@@ -66,7 +66,7 @@ class VarTag(xml.Tag):
       self.parser_error("VarTag Tag requires attribute var")
     wmask.add_vartag(self)
     self.build_widget(wmask)
-    if self.widget is not None:
+    if self.widget != None:
       wlabel=gui.widget.Label(wmask,text=self.label,bg=cfg.frame_bg_,maxline=cfg.mask_label_size_)
       wmask.add_widget_w(wlabel,wmask.x,wmask.y,cspan=cfg.mask_label_width_)
       wmask.column(advance=cfg.mask_label_width_)
@@ -202,7 +202,7 @@ class EntryAbsTag(VarTag):
       self.build_sub()
     except Exception as e:
       err=str(e)
-    if err is not None:
+    if err != None:
       self.parser_error(err)  
   
   def build_sub(self):
@@ -231,7 +231,7 @@ class EntryTag(EntryAbsTag):
     value=self.widget.get_value()
     self.check_data(value)
     self.data=[]
-    if value is not '':
+    if value != '':
       self.data.append(value)
 
   def build_sub(self):
@@ -255,7 +255,7 @@ class ListEntryTag(EntryAbsTag):
     self.data=[]
     for v in value:
       self.check_data(v)
-      if value is not '':
+      if value != '':
         self.data.append(v)
  
   def build_sub(self):
@@ -554,11 +554,11 @@ class TreeTag(xml.Tag):
         self.attrs.append((t,value))
        
   def if_check(self,var):
-    if self.if_ is not None:
+    if self.if_ != None:
       v=pycode.data_dict_value(self.if_,var)
       if len(v) == 0:
         return False
-    if self.ifnot_ is not None:
+    if self.ifnot_ != None:
       v=pycode.data_dict_value(self.ifnot_,var)
       if not len(v) == 0:
         return False
@@ -650,7 +650,7 @@ def parse(filepath,mask):
     root=parser.get_root()
     i=0
     tag=root.get_child(i)
-    while tag is not None:
+    while tag != None:
       tag.build_mask(mask)
       i=i+1
       tag=root.get_child(i)
